@@ -1,7 +1,7 @@
 package Bencher::Scenario::GraphTopologicalSortModules;
 
 our $DATE = '2019-02-15'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -153,7 +153,7 @@ Bencher::Scenario::GraphTopologicalSortModules - Benchmark graph topological sor
 
 =head1 VERSION
 
-This document describes version 0.004 of Bencher::Scenario::GraphTopologicalSortModules (from Perl distribution Bencher-Scenario-GraphTopologicalSortModules), released on 2019-02-15.
+This document describes version 0.005 of Bencher::Scenario::GraphTopologicalSortModules (from Perl distribution Bencher-Scenario-GraphTopologicalSortModules), released on 2019-02-15.
 
 =head1 SYNOPSIS
 
@@ -177,7 +177,7 @@ Version numbers shown below are the versions used when running the sample benchm
 
 L<Algorithm::Dependency> 1.111
 
-L<Data::Graph::Util> 0.005
+L<Data::Graph::Util> 0.006
 
 L<Sort::Topological> 0.02
 
@@ -223,6 +223,18 @@ Code template:
 
 =item * 100nodes-100edges
 
+=item * empty (not included by default)
+
+=item * 100nodes-500edges (not included by default)
+
+=item * cyclic1 (not included by default)
+
+=item * cyclic2 (not included by default)
+
+=item * cyclic3 (not included by default)
+
+=item * cyclic4 (not included by default)
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -235,18 +247,18 @@ Benchmark with default options (C<< bencher -m GraphTopologicalSortModules >>):
  +-----------------------------+-------------------+-----------+-----------+------------+---------+---------+
  | participant                 | dataset           | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-----------------------------+-------------------+-----------+-----------+------------+---------+---------+
- | Sort::Topological::toposort | 100nodes-100edges |     160   | 6.4       |       1    | 1.2e-05 |      20 |
- | Sort::Topological::toposort | 10nodes-35edges   |     940   | 1.1       |       6    |   4e-06 |      22 |
- | Algorithm::Dependency       | 100nodes-100edges |     970   | 1         |       6.2  | 2.5e-06 |      20 |
- | Data::Graph::Util::toposort | 100nodes-100edges |    4600   | 0.22      |      29    | 4.3e-07 |      20 |
- | Algorithm::Dependency       | 10nodes-35edges   |    9900   | 0.1       |      63    | 1.3e-07 |      20 |
- | Algorithm::Dependency       | 6nodes-7edges     |   21000   | 0.048     |     130    | 5.3e-08 |      20 |
- | Sort::Topological::toposort | 6nodes-7edges     |   23422.3 | 0.0426943 |     149.59 | 1.2e-11 |      20 |
- | Data::Graph::Util::toposort | 10nodes-35edges   |   34300   | 0.0292    |     219    | 1.3e-08 |      20 |
- | Algorithm::Dependency       | 2nodes-1edge      |   45000   | 0.022     |     290    |   8e-08 |      20 |
- | Data::Graph::Util::toposort | 6nodes-7edges     |   65900   | 0.0152    |     421    | 6.7e-09 |      20 |
- | Sort::Topological::toposort | 2nodes-1edge      |  138000   | 0.00725   |     880    | 3.3e-09 |      20 |
- | Data::Graph::Util::toposort | 2nodes-1edge      |  160000   | 0.0062    |    1000    | 2.2e-08 |      20 |
+ | Sort::Topological::toposort | 100nodes-100edges |        45 |   22      |          1 | 7.5e-05 |      20 |
+ | Sort::Topological::toposort | 10nodes-35edges   |       980 |    1      |         22 | 1.4e-06 |      20 |
+ | Algorithm::Dependency       | 100nodes-100edges |       990 |    1      |         22 | 9.3e-06 |      20 |
+ | Data::Graph::Util::toposort | 100nodes-100edges |      1300 |    0.76   |         29 | 9.1e-07 |      20 |
+ | Algorithm::Dependency       | 6nodes-7edges     |      5500 |    0.18   |        120 | 4.8e-07 |      20 |
+ | Data::Graph::Util::toposort | 10nodes-35edges   |      8900 |    0.11   |        200 | 2.7e-07 |      20 |
+ | Algorithm::Dependency       | 10nodes-35edges   |      9800 |    0.1    |        220 | 5.3e-07 |      22 |
+ | Algorithm::Dependency       | 2nodes-1edge      |     12000 |    0.084  |        270 | 2.2e-07 |      23 |
+ | Data::Graph::Util::toposort | 6nodes-7edges     |     19000 |    0.054  |        410 | 1.8e-07 |      21 |
+ | Sort::Topological::toposort | 6nodes-7edges     |     24000 |    0.043  |        520 | 1.1e-07 |      20 |
+ | Data::Graph::Util::toposort | 2nodes-1edge      |     47000 |    0.021  |       1000 | 4.1e-08 |      34 |
+ | Sort::Topological::toposort | 2nodes-1edge      |    150000 |    0.0068 |       3300 | 1.3e-08 |      20 |
  +-----------------------------+-------------------+-----------+-----------+------------+---------+---------+
 
 
@@ -256,10 +268,10 @@ Benchmark module startup overhead (C<< bencher -m GraphTopologicalSortModules --
  +-----------------------+-----------+------------------------+------------+---------+---------+
  | participant           | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +-----------------------+-----------+------------------------+------------+---------+---------+
- | Algorithm::Dependency |      13   |                    7.7 |        1   | 3.6e-05 |      21 |
- | Data::Graph::Util     |       8.1 |                    2.8 |        1.7 | 2.9e-05 |      20 |
- | Sort::Topological     |       8.1 |                    2.8 |        1.7 |   3e-05 |      20 |
- | perl -e1 (baseline)   |       5.3 |                    0   |        2.6 |   2e-05 |      20 |
+ | Algorithm::Dependency |      42   |                   28.4 |       1    |   7e-05 |      20 |
+ | Sort::Topological     |      24   |                   10.4 |       1.8  | 7.4e-05 |      23 |
+ | Data::Graph::Util     |      22.8 |                    9.2 |       1.86 | 2.1e-05 |      20 |
+ | perl -e1 (baseline)   |      13.6 |                    0   |       3.12 | 9.9e-06 |      20 |
  +-----------------------+-----------+------------------------+------------+---------+---------+
 
 
