@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::GraphTopologicalSortModules;
 
-our $VERSION = 0.004; # VERSION
+our $VERSION = 0.005; # VERSION
 
 our $results = [
   [
@@ -9,112 +9,112 @@ our $results = [
     [
       {
         dataset     => "100nodes-100edges",
-        errors      => 1.2e-05,
+        errors      => 7.5e-05,
         participant => "Sort::Topological::toposort",
-        rate        => 160,
+        rate        => 45,
         samples     => 20,
-        time        => 6.4,
+        time        => 22,
         vs_slowest  => 1,
       },
       {
         dataset     => "10nodes-35edges",
-        errors      => 4e-06,
+        errors      => 1.4e-06,
         participant => "Sort::Topological::toposort",
-        rate        => 940,
-        samples     => 22,
-        time        => 1.1,
-        vs_slowest  => 6,
-      },
-      {
-        dataset     => "100nodes-100edges",
-        errors      => 2.5e-06,
-        participant => "Algorithm::Dependency",
-        rate        => 970,
+        rate        => 980,
         samples     => 20,
         time        => 1,
-        vs_slowest  => 6.2,
+        vs_slowest  => 22,
       },
       {
         dataset     => "100nodes-100edges",
-        errors      => 4.3e-07,
-        participant => "Data::Graph::Util::toposort",
-        rate        => 4600,
+        errors      => 9.3e-06,
+        participant => "Algorithm::Dependency",
+        rate        => 990,
         samples     => 20,
-        time        => 0.22,
+        time        => 1,
+        vs_slowest  => 22,
+      },
+      {
+        dataset     => "100nodes-100edges",
+        errors      => 9.1e-07,
+        participant => "Data::Graph::Util::toposort",
+        rate        => 1300,
+        samples     => 20,
+        time        => 0.76,
         vs_slowest  => 29,
       },
       {
-        dataset     => "10nodes-35edges",
-        errors      => 1.3e-07,
+        dataset     => "6nodes-7edges",
+        errors      => 4.8e-07,
         participant => "Algorithm::Dependency",
-        rate        => 9900,
+        rate        => 5500,
         samples     => 20,
+        time        => 0.18,
+        vs_slowest  => 120,
+      },
+      {
+        dataset     => "10nodes-35edges",
+        errors      => 2.7e-07,
+        participant => "Data::Graph::Util::toposort",
+        rate        => 8900,
+        samples     => 20,
+        time        => 0.11,
+        vs_slowest  => 200,
+      },
+      {
+        dataset     => "10nodes-35edges",
+        errors      => 5.3e-07,
+        participant => "Algorithm::Dependency",
+        rate        => 9800,
+        samples     => 22,
         time        => 0.1,
-        vs_slowest  => 63,
+        vs_slowest  => 220,
       },
       {
-        dataset     => "6nodes-7edges",
-        errors      => 5.3e-08,
+        dataset     => "2nodes-1edge",
+        errors      => 2.2e-07,
         participant => "Algorithm::Dependency",
-        rate        => 21000,
-        samples     => 20,
-        time        => 0.048,
-        vs_slowest  => 130,
+        rate        => 12000,
+        samples     => 23,
+        time        => 0.084,
+        vs_slowest  => 270,
       },
       {
         dataset     => "6nodes-7edges",
-        errors      => 1.2e-11,
-        participant => "Sort::Topological::toposort",
-        rate        => 23422.3,
-        samples     => 20,
-        time        => 0.0426943,
-        vs_slowest  => 149.59,
-      },
-      {
-        dataset     => "10nodes-35edges",
-        errors      => 1.3e-08,
+        errors      => 1.8e-07,
         participant => "Data::Graph::Util::toposort",
-        rate        => 34300,
-        samples     => 20,
-        time        => 0.0292,
-        vs_slowest  => 219,
-      },
-      {
-        dataset     => "2nodes-1edge",
-        errors      => 8e-08,
-        participant => "Algorithm::Dependency",
-        rate        => 45000,
-        samples     => 20,
-        time        => 0.022,
-        vs_slowest  => 290,
+        rate        => 19000,
+        samples     => 21,
+        time        => 0.054,
+        vs_slowest  => 410,
       },
       {
         dataset     => "6nodes-7edges",
-        errors      => 6.7e-09,
-        participant => "Data::Graph::Util::toposort",
-        rate        => 65900,
-        samples     => 20,
-        time        => 0.0152,
-        vs_slowest  => 421,
-      },
-      {
-        dataset     => "2nodes-1edge",
-        errors      => 3.3e-09,
+        errors      => 1.1e-07,
         participant => "Sort::Topological::toposort",
-        rate        => 138000,
+        rate        => 24000,
         samples     => 20,
-        time        => 0.00725,
-        vs_slowest  => 880,
+        time        => 0.043,
+        vs_slowest  => 520,
       },
       {
         dataset     => "2nodes-1edge",
-        errors      => 2.2e-08,
+        errors      => 4.1e-08,
         participant => "Data::Graph::Util::toposort",
-        rate        => 160000,
-        samples     => 20,
-        time        => 0.0062,
+        rate        => 47000,
+        samples     => 34,
+        time        => 0.021,
         vs_slowest  => 1000,
       },
+      {
+        dataset     => "2nodes-1edge",
+        errors      => 1.3e-08,
+        participant => "Sort::Topological::toposort",
+        rate        => 150000,
+        samples     => 20,
+        time        => 0.0068,
+        vs_slowest  => 3300,
+      },
     ],
     {
       "func.bencher_args"              => {
@@ -238,7 +238,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2539.294,
+                                              speed                        => 799.975,
                                               stepping                     => 4,
                                             },
                                             {
@@ -354,7 +354,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2686.523,
+                                              speed                        => 799.975,
                                               stepping                     => 4,
                                             },
                                             {
@@ -470,7 +470,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2861.523,
+                                              speed                        => 800.061,
                                               stepping                     => 4,
                                             },
                                             {
@@ -586,11 +586,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2726.257,
+                                              speed                        => 799.975,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.51482892036438,
+      "func.elapsed_time"              => 0.84033203125,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.042,
@@ -598,7 +598,7 @@ our $results = [
                                             "Algorithm::Dependency::Source::HoA" => 1.111,
                                             "Bencher::Scenario::GraphTopologicalSortModules" => undef,
                                             "Benchmark::Dumb" => 0.111,
-                                            "Data::Graph::Util" => 0.005,
+                                            "Data::Graph::Util" => 0.006,
                                             "Devel::Platform::Info" => 0.16,
                                             "perl" => "v5.26.1",
                                             "Sort::Topological" => 0.02,
@@ -635,9 +635,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1550165242,
       "func.scenario_module_sha1sum"   => "2f81b7878850d7c69e349c71bb55b7af43fe6832",
       "func.scenario_module_sha256sum" => "b473d5fd950595b19e1d363985c65198da514c818f8759e1840ee5c89969ea03",
-      "func.time_end"                  => 1550165448.74325,
+      "func.time_end"                  => 1550166465.92413,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1550165448.22842,
+      "func.time_start"                => 1550166465.0838,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
